@@ -21,7 +21,7 @@ Configuration
 Usage
 -------
 
-.. rst:directive:: installation
+.. rst:directive:: .. installation:: name
 
 	Adds a series of tabs providing installation instructions for the project from a number of sources.
 
@@ -303,6 +303,10 @@ def pypi_installation(
 
 	:param options: Mapping of option names to values.
 	:param env: The Sphinx build environment.
+
+	:rtype:
+
+	.. clearpage::
 	"""
 
 	if "pypi-name" in options:
