@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 #
 #  issues.py
-"""
+r"""
 Add links to GitHub issues and Pull Requests.
 
 .. extensions:: sphinx_toolbox.issues
@@ -90,6 +90,7 @@ API Reference
 	* :func:`~.depart_issue_node`
 	* :func:`~.get_issue_title`
 
+.. latex:vspace:: 10px
 
 """
 #
@@ -155,7 +156,7 @@ class IssueNode(sphinx_toolbox.github.issues.IssueNode):
 	@deprecated(
 			deprecated_in="2.4.0",
 			removed_in="3.0.0",
-			current_version="2.10.0",
+			current_version="2.11.0",
 			details="Import from 'sphinx_toolbox.github.issues' instead.",
 			name="IssueNode",
 			)
@@ -166,7 +167,7 @@ class IssueNode(sphinx_toolbox.github.issues.IssueNode):
 visit_issue_node = deprecated(
 		deprecated_in="2.4.0",
 		removed_in="3.0.0",
-		current_version="2.10.0",
+		current_version="2.11.0",
 		details="Import from 'sphinx_toolbox.github.issues' instead.",
 		func=sphinx_toolbox.github.issues.visit_issue_node,
 		)
@@ -174,7 +175,7 @@ visit_issue_node = deprecated(
 depart_issue_node = deprecated(
 		deprecated_in="2.4.0",
 		removed_in="3.0.0",
-		current_version="2.10.0",
+		current_version="2.11.0",
 		details="Import from 'sphinx_toolbox.github.issues' instead.",
 		func=sphinx_toolbox.github.issues.depart_issue_node,
 		)
@@ -182,7 +183,7 @@ depart_issue_node = deprecated(
 get_issue_title = deprecated(
 		deprecated_in="2.4.0",
 		removed_in="3.0.0",
-		current_version="2.10.0",
+		current_version="2.11.0",
 		details="Import from 'sphinx_toolbox.github.issues' instead.",
 		func=sphinx_toolbox.github.issues.get_issue_title,
 		)
