@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 #
 #  sourcelink.py
-"""
+r"""
 Show a link to the corresponding source code at the top of :rst:dir:`automodule` output.
 
 .. versionadded:: 0.6.0
@@ -11,9 +11,18 @@ Show a link to the corresponding source code at the top of :rst:dir:`automodule`
 Configuration
 ----------------
 
+.. raw:: latex
+
+	\begin{flushleft}
+
 :mod:`sphinx_toolbox.more_autodoc.sourcelink` can be configured using the :confval:`autodoc_default_options`
 option in ``conf.py``, or with the :rst:dir:`:sourcelink: <sourcelink>` option flag to :rst:dir:`automodule`.
 
+.. raw:: latex
+
+	\end{flushleft}
+
+
 .. confval:: autodoc_show_sourcelink
 	:type: :class:`bool`
 	:default: :py:obj:`False`
@@ -64,6 +73,7 @@ from types import ModuleType
 from typing import Any, List, Mapping
 
 # 3rd party
+import autodocsumm  # type: ignore
 import sphinx.ext.autodoc
 from sphinx.application import Sphinx
 
@@ -117,6 +127,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 
 	sphinx.ext.autodoc.ModuleDocumenter.option_spec["sourcelink"] = flag
+	autodocsumm.AutoSummModuleDocumenter.option_spec["sourcelink"] = flag
 
 	app.setup_extension("sphinx_toolbox.source")
 	app.setup_extension("sphinx_toolbox._css")
