@@ -7,10 +7,7 @@ Add hyperlinks to source files, either on GitHub or in the documentation itself.
 .. extensions:: sphinx_toolbox.source
 
 If you're looking for a ``[source]`` button to go at the end of your class and
-function signatures, checkout
-`sphinx.ext.linkcode <https://www.sphinx-doc.org/en/master/usage/extensions/linkcode.html>`__
-and
-`sphinx.ext.viewcode <https://www.sphinx-doc.org/en/master/usage/extensions/viewcode.html>`__
+function signatures, checkout :mod:`sphinx.ext.linkcode` and :mod:`sphinx.ext.viewcode`.
 
 
 Usage
@@ -27,7 +24,7 @@ Usage
 
 .. rst:role:: source
 
-	Shows a link to the given source file, either on GitHub or within the Sphinx documentation.
+	Role which shows a link to the given source file, either on GitHub or within the Sphinx documentation.
 
 	By default, the link points to the code within the documentation,
 	but can be configured to point to GitHub by setting :confval:`source_link_target` to ``'GitHub'``.
@@ -86,7 +83,7 @@ from sphinx.util import split_explicit_title
 # this package
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["source_role"]
+__all__ = ["source_role", "setup"]
 
 # TODO: rawstring: Return it as a problematic node linked to a system message if a problem is encountered.
 
@@ -99,7 +96,7 @@ def source_role(
 		inliner: Inliner,
 		options: Dict = {},
 		content: List[str] = []
-		) -> Tuple[Sequence[Union[nodes.reference, addnodes.only]], List[system_message]]:
+		) -> Tuple[Sequence[Union[nodes.reference, addnodes.pending_xref]], List[system_message]]:
 	"""
 	Adds a link to the given Python source file in the documentation or on GitHub.
 
@@ -116,6 +113,13 @@ def source_role(
 		To be interpreted by the function.
 
 	:return: A list containing the created node, and a list containing any messages generated during the function.
+
+	.. versionchanged:: 2.8.0
+
+		Now returns a sequence of :class:`nodes.reference <docutils.nodes.reference>` and
+		:class:`addnodes.pending_xref <sphinx.addnodes.pending_xref>` as the first tuple element,
+		rather than :class:`nodes.reference <docutils.nodes.reference>` and
+		:class:`addnodes.pending_xref <sphinx.addnodes.only>` as in previous versions.
 	"""
 
 	has_t, title, target = split_explicit_title(text)
@@ -125,14 +129,15 @@ def source_role(
 	env = inliner.document.settings.env
 	config = env.app.config
 
-	nodes_: List[Union[nodes.reference, addnodes.only]] = []
+	nodes_: List[Union[nodes.reference, addnodes.pending_xref]] = []
 	messages: List[system_message] = []
-	refnode: Union[nodes.reference, addnodes.only]
+	refnode: Union[nodes.reference, addnodes.pending_xref]
 
 	if config.source_link_target == "sphinx":
 		pagename = "_modules/" + target.replace(".py", '')
-		refnode = addnodes.only(expr="html")
-		refnode += addnodes.pending_xref(
+		# refnode = addnodes.only(expr="html")
+		# refnode += addnodes.pending_xref(
+		refnode = addnodes.pending_xref(
 				title,
 				nodes.inline(title, title),
 				reftype="viewcode",
@@ -166,7 +171,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.source`.
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	# Link to source code
